@@ -113,7 +113,7 @@ public:
      */
     static CreateJob *create(const QString &fileName,
                              const QString &mimeType,
-                             const QVector<Archive::Entry *> &entries,
+                             const QList<Archive::Entry *> &entries,
                              const CompressionOptions &options,
                              QObject *parent = nullptr);
 
@@ -145,11 +145,11 @@ public:
     ArchiveError error() const;
     bool isValid() const;
 
-    DeleteJob *deleteFiles(QVector<Archive::Entry *> &entries);
+    DeleteJob *deleteFiles(QList<Archive::Entry *> &entries);
     CommentJob *addComment(const QString &comment);
     TestJob *testArchive();
 
-    AddJob *addFiles(const QVector<Archive::Entry *> &files, const Archive::Entry *destination, const CompressionOptions &options = CompressionOptions());
+    AddJob *addFiles(const QList<Archive::Entry *> &files, const Archive::Entry *destination, const CompressionOptions &options = CompressionOptions());
 
     /**
      * Renames or moves entries within the archive.
@@ -161,7 +161,7 @@ public:
      * Otherwise (if count is more than 1) it's moving, so destination must contain only targeted folder path
      * or be empty, if moving to the root.
      */
-    MoveJob *moveFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options = CompressionOptions());
+    MoveJob *moveFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options = CompressionOptions());
 
     /**
      * Copies entries within the archive.
@@ -170,9 +170,9 @@ public:
      * @param destination Destination path. It must contain only targeted folder path or be empty,
      * if copying to the root.
      */
-    CopyJob *copyFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options = CompressionOptions());
+    CopyJob *copyFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options = CompressionOptions());
 
-    ExtractJob *extractFiles(const QVector<Archive::Entry *> &files, const QString &destinationDir, ExtractionOptions options = ExtractionOptions());
+    ExtractJob *extractFiles(const QList<Archive::Entry *> &files, const QString &destinationDir, ExtractionOptions options = ExtractionOptions());
 
     PreviewJob *preview(Archive::Entry *entry);
     OpenJob *open(Archive::Entry *entry);
